package com.tsky.selfcare.profileUpdate.phaselistener;

/***********************************************************************************************************************************************
 * 
 * This class implements the PhaseListener and overrides the required methods.
 * This will provide room for the developer to write his/her own logic before delivering the page to client.
 * 
 *************************************************************************************************************************************************/
import java.io.Serializable;

import javax.faces.context.FacesContext;
import javax.faces.event.PhaseEvent;
import javax.faces.event.PhaseId;
import javax.faces.event.PhaseListener;

import org.apache.log4j.Logger;
import org.infinispan.Cache;

import com.tsky.selfcare.cache.SubscriberInfo;
import com.tsky.selfcare.customexceptions.BusinessException;
import com.tsky.selfcare.customexceptions.PortalException;
import com.tsky.selfcare.profileUpdate.bean.ProfileUpdateBean;
import com.tsky.selfcare.util.jcache.SubscriberCache;
public class CustomPhaseListener implements PhaseListener,Serializable
{
	private static final long serialVersionUID = 0;
	private Logger log = Logger.getLogger(this.getClass());
	
	public PhaseId getPhaseId() 
	{		
		return PhaseId.RENDER_RESPONSE;
	}
	
	/* This method is an overridden method of PhaseListener.  This method will be called before rendering the response to client.
	 * We are preloading the bean in this method if it is first request.  And we are managing validation errors on submitting the update page form 
	 * through clicking save button and through changing the value in state combo.
	 * @see javax.faces.event.PhaseListener#beforePhase(javax.faces.event.PhaseEvent)
	 */
	public void beforePhase(PhaseEvent e) 
	{
		log.info("Entered beforePhase method");
		FacesContext facesContext = null;
		try
		{
			facesContext = e.getFacesContext();	
			
			ProfileUpdateBean profileBean = (ProfileUpdateBean)facesContext.getApplication().getVariableResolver().resolveVariable(facesContext, "profileUpdateBean");
			log.info("Bean Initialization::::"+profileBean);
			if(profileBean.isFirstRequest())
			{
				SubscriberCache subscriberCache = SubscriberCache.getSubscriberCacheInstance();
				Cache cache=subscriberCache.getPojoCacheInstance();
				System.out.println("cache :::"+cache);
				//log.info(subscriberID + "~Creating the instance of SubscriberInfo");
				SubscriberInfo subInfo = new SubscriberInfo();
				subInfo.setMessage("Welcome To Gatein....");
				cache.put("100000000", subInfo);
				log.info("fgffffffffffff");
				profileBean.getProfile();
			}			
	}
	catch(PortalException pe)
	{			
		if(null!= facesContext)
		{							
			facesContext.getApplication().getNavigationHandler().handleNavigation(facesContext, "", "error" );
		}	
	}
	catch(BusinessException be)
	{			
		if(null!= facesContext)
		{							
			facesContext.getApplication().getNavigationHandler().handleNavigation(facesContext, "", "error" );
		}	
	}
	catch(NullPointerException ne)
	{		
		log.info("i am in NullPointerException");
		if(null!= facesContext)
		{							
			facesContext.getApplication().getNavigationHandler().handleNavigation(facesContext, "", "error" );
		}	
	}
	log.info("Exit beforePhase method");
 }
	
	
	/* This method will be called after renderig the response to client.
	 * @see javax.faces.event.PhaseListener#afterPhase(javax.faces.event.PhaseEvent)
	 */
	public void afterPhase(PhaseEvent e) 
	{		
		log.info("I am in After Phase Method");
		//Setting the submitRequest to true.
		//FacesContext facesContext=e.getFacesContext();
		//ProfileUpdateBean profileBean=(ProfileUpdateBean)facesContext.getApplication().getVariableResolver().resolveVariable(facesContext, "profileUpdateBean");
		//profileBean.setSubmitRequest(true);
		SubscriberCache subscriberCache = SubscriberCache.getSubscriberCacheInstance();
		Cache cache=subscriberCache.getPojoCacheInstance();
		System.out.println("cache :::"+cache);
		//log.info(subscriberID + "~Creating the instance of SubscriberInfo");
		SubscriberInfo subInfo = new SubscriberInfo();
		//log.info(subscriberID + "~Getting the Object from cache instance");
		subInfo = (SubscriberInfo)cache.get("100000000");
		System.out.println("SubscriberInfo:::"+subInfo.getMessage());
	}

}
